TestFlows - Connect
===================

**The connect module is still work in progress and is currently under development.
Please use it only for reference.**

Minimal module to provide capabilities to connect to
and control CLI programs.

Currently supports only Python 3.6 or above.

Installation
************

.. code-block:: bash

    $ ./build; ./install

where

.. code-block:: bash

    $ ./build

creates a pip installable package in *./dist*, for example

.. code-block:: bash

    $ ls dist/
    testflows.connect-1.2.190905.123636.tar.gz

and

.. code-block:: bash

    $ ./install

installs the *testflows.connect* module.
